@@ -23,8 +23,7 @@
     SOFTWARE.
 */
 
-#ifndef SAIL_IMAGE_CPP_H
-#define SAIL_IMAGE_CPP_H
+#pragma once
 
 #include <cstddef> /* std::size_t */
 #include <memory>
@@ -37,8 +36,8 @@
 
 #include <sail-c++/iccp.h>
 #include <sail-c++/palette.h>
-#include <sail-c++/source_image.h>
 #include <sail-c++/resolution.h>
+#include <sail-c++/source_image.h>
 
 struct sail_image;
 
@@ -67,7 +66,7 @@ public:
      * Constructs a new image out of the specified file path. Reads just a single frame
      * from the file.
      */
-    explicit image(const std::string &path);
+    explicit image(const std::string& path);
 
     /*
      * Constructs a new image out of the specified image properties and allocates the pixels
@@ -87,33 +86,33 @@ public:
      * Assumes the pixels have no padding bytes in the end of every scan line. The pixels
      * must remain valid as long as the image exists.
      */
-    image(void *pixels, SailPixelFormat pixel_format, unsigned width, unsigned height);
+    image(void* pixels, SailPixelFormat pixel_format, unsigned width, unsigned height);
 
     /*
      * Constructs a new image out of the specified image properties and the pixels.
      * The pixels must remain valid as long as the image exists.
      */
-    image(void *pixels, SailPixelFormat pixel_format, unsigned width, unsigned height, unsigned bytes_per_line);
+    image(void* pixels, SailPixelFormat pixel_format, unsigned width, unsigned height, unsigned bytes_per_line);
 
     /*
      * Makes a deep copy of the image.
      */
-    image(const image &img);
+    image(const image& img);
 
     /*
      * Makes a deep copy of the image.
      */
-    image& operator=(const sail::image &image);
+    image& operator=(const sail::image& image);
 
     /*
      * Moves the image.
      */
-    image(sail::image &&image) noexcept;
+    image(sail::image&& image) noexcept;
 
     /*
      * Moves the image.
      */
-    image& operator=(sail::image &&image) noexcept;
+    image& operator=(sail::image&& image) noexcept;
 
     /*
      * Destroys the image and the deep copied pixel data.
@@ -256,6 +255,14 @@ public:
      */
     const sail::source_image& source_image() const;
 
+    /*
+     * Returns the editable source image properties.
+     *
+     * LOAD: Set by SAIL to valid source image properties of the original image.
+     * SAVE: Ignored.
+     */
+    sail::source_image& source_image();
+
     /*
      * Returns the editable pixel data if any. The channels are interleaved per pixel.
      * The pixels are organized row by row, left to right, top to bottom.
@@ -292,12 +299,12 @@ public:
     /*
      * Sets a new resolution.
      */
-    void set_resolution(const sail::resolution &resolution);
+    void set_resolution(const sail::resolution& resolution);
 
     /*
      * Sets a new resolution.
      */
-    void set_resolution(sail::resolution &&resolution) noexcept;
+    void set_resolution(sail::resolution&& resolution) noexcept;
 
     /*
      * Sets a new gamma.
@@ -312,32 +319,32 @@ public:
     /*
      * Sets a new palette.
      */
-    void set_palette(const sail::palette &palette);
+    void set_palette(const sail::palette& palette);
 
     /*
      * Sets a new palette.
      */
-    void set_palette(sail::palette &&palette) noexcept;
+    void set_palette(sail::palette&& palette) noexcept;
 
     /*
      * Sets new meta data.
      */
-    void set_meta_data(const std::vector<sail::meta_data> &meta_data);
+    void set_meta_data(const std::vector<sail::meta_data>& meta_data);
 
     /*
      * Sets new meta data.
      */
-    void set_meta_data(std::vector<sail::meta_data> &&meta_data) noexcept;
+    void set_meta_data(std::vector<sail::meta_data>&& meta_data) noexcept;
 
     /*
      * Sets a new ICC profile.
      */
-    void set_iccp(const sail::iccp &iccp);
+    void set_iccp(const sail::iccp& iccp);
 
     /*
      * Sets a new ICC profile.
      */
-    void set_iccp(sail::iccp &&iccp) noexcept;
+    void set_iccp(sail::iccp&& iccp) noexcept;
 
     /*
      * Replaces the image with the image from the specified file path. Reads just a single frame
@@ -345,14 +352,14 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t load(const std::string &path);
+    sail_status_t load(const std::string& path);
 
     /*
      * Saves the image with into the specified file path.
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t save(const std::string &path);
+    sail_status_t save(const std::string& path);
 
     /*
      * Returns true if the image can be converted into the specified pixel format.
@@ -393,7 +400,7 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert(SailPixelFormat pixel_format, const conversion_options &options);
+    sail_status_t convert(SailPixelFormat pixel_format, const conversion_options& options);
 
     /*
      * Converts the image to the best pixel format for saving. Use can_convert()
@@ -413,7 +420,7 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert(const sail::save_features &save_features);
+    sail_status_t convert(const sail::save_features& save_features);
 
     /*
      * Converts the image to the best pixel format for saving using the specified conversion options.
@@ -429,7 +436,7 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert(const sail::save_features &save_features, const conversion_options &options);
+    sail_status_t convert(const sail::save_features& save_features, const conversion_options& options);
 
     /*
      * Converts the image to the specified pixel format and assigns the resulting image to the 'image' argument.
@@ -447,7 +454,7 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert_to(SailPixelFormat pixel_format, sail::image *image) const;
+    sail_status_t convert_to(SailPixelFormat pixel_format, sail::image* image) const;
 
     /*
      * Converts the image to the specified pixel format using the specified conversion options
@@ -462,7 +469,7 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert_to(SailPixelFormat pixel_format, const conversion_options &options, sail::image *image) const;
+    sail_status_t convert_to(SailPixelFormat pixel_format, const conversion_options& options, sail::image* image) const;
 
     /*
      * Converts the image to the best pixel format for saving and assigns the resulting image to the 'image' argument.
@@ -480,7 +487,7 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert_to(const sail::save_features &save_features, sail::image *image) const;
+    sail_status_t convert_to(const sail::save_features& save_features, sail::image* image) const;
 
     /*
      * Converts the image to the best pixel format for saving using the specified conversion options
@@ -495,7 +502,9 @@ public:
      *
      * Returns SAIL_OK on success.
      */
-    sail_status_t convert_to(const sail::save_features &save_features, const conversion_options &options, sail::image *image) const;
+    sail_status_t convert_to(const sail::save_features& save_features,
+                             const conversion_options& options,
+                             sail::image* image) const;
 
     /*
      * Converts the image to the specified pixel format and returns the resulting image.
@@ -528,7 +537,7 @@ public:
      *
      * Returns an invalid image on error.
      */
-    image convert_to(SailPixelFormat pixel_format, const conversion_options &options) const;
+    image convert_to(SailPixelFormat pixel_format, const conversion_options& options) const;
 
     /*
      * Converts the image to the best pixel format for saving and returns the resulting image.
@@ -546,7 +555,7 @@ public:
      *
      * Returns an invalid image on error.
      */
-    image convert_to(const sail::save_features &save_features) const;
+    image convert_to(const sail::save_features& save_features) const;
 
     /*
      * Converts the image to the best pixel format for saving using the specified conversion options
@@ -561,7 +570,7 @@ public:
      *
      * Returns an invalid image on error.
      */
-    image convert_to(const sail::save_features &save_features, const conversion_options &options) const;
+    image convert_to(const sail::save_features& save_features, const conversion_options& options) const;
 
     /*
      * Returns the closest pixel format from the list.
@@ -570,7 +579,7 @@ public:
      *
      * Returns SAIL_PIXEL_FORMAT_UNKNOWN if no candidates found at all.
      */
-    SailPixelFormat closest_pixel_format(const std::vector<SailPixelFormat> &pixel_formats) const;
+    SailPixelFormat closest_pixel_format(const std::vector<SailPixelFormat>& pixel_formats) const;
 
     /*
      * Returns the closest pixel format from the save features.
@@ -579,7 +588,7 @@ public:
      *
      * Returns SAIL_PIXEL_FORMAT_UNKNOWN if no candidates found at all.
      */
-    SailPixelFormat closest_pixel_format(const sail::save_features &save_features) const;
+    SailPixelFormat closest_pixel_format(const sail::save_features& save_features) const;
 
     /*
      * Mirrors the image horizontally or vertically.
@@ -592,6 +601,50 @@ public:
      */
     sail_status_t mirror(SailOrientation orientation);
 
+    /*
+     * Rotates the image by 90, 180, or 270 degrees clockwise.
+     *
+     * Updates the image dimensions and pixels.
+     *
+     * All pixel formats with byte-aligned pixels (bits_per_pixel % 8 == 0) are supported.
+     *
+     * Supported angles:
+     *   - SAIL_ORIENTATION_ROTATED_90
+     *   - SAIL_ORIENTATION_ROTATED_180
+     *   - SAIL_ORIENTATION_ROTATED_270
+     *
+     * Returns SAIL_OK on success.
+     */
+    sail_status_t rotate(SailOrientation angle);
+
+    /*
+     * Rotates the image by 90, 180, or 270 degrees clockwise and assigns the result to the 'image' argument.
+     *
+     * All pixel formats with byte-aligned pixels (bits_per_pixel % 8 == 0) are supported.
+     *
+     * Supported angles:
+     *   - SAIL_ORIENTATION_ROTATED_90
+     *   - SAIL_ORIENTATION_ROTATED_180
+     *   - SAIL_ORIENTATION_ROTATED_270
+     *
+     * Returns SAIL_OK on success.
+     */
+    sail_status_t rotate_to(SailOrientation angle, sail::image* image) const;
+
+    /*
+     * Rotates the image by 90, 180, or 270 degrees clockwise and returns the resulting image.
+     *
+     * All pixel formats with byte-aligned pixels (bits_per_pixel % 8 == 0) are supported.
+     *
+     * Supported angles:
+     *   - SAIL_ORIENTATION_ROTATED_90
+     *   - SAIL_ORIENTATION_ROTATED_180
+     *   - SAIL_ORIENTATION_ROTATED_270
+     *
+     * Returns an invalid image on error.
+     */
+    image rotate_to(SailOrientation angle) const;
+
     /*
      * Returns true if the conversion or updating functions can convert or update from the input
      * pixel format to the output pixel format.
@@ -605,7 +658,8 @@ public:
      *
      * Returns SAIL_PIXEL_FORMAT_UNKNOWN if no candidates found at all.
      */
-    static SailPixelFormat closest_pixel_format(SailPixelFormat input_pixel_format, const std::vector<SailPixelFormat> &pixel_formats);
+    static SailPixelFormat closest_pixel_format(SailPixelFormat input_pixel_format,
+                                                const std::vector<SailPixelFormat>& pixel_formats);
 
     /*
      * Returns the closest pixel format to the input pixel format from the save features.
@@ -614,7 +668,14 @@ public:
      *
      * Returns SAIL_PIXEL_FORMAT_UNKNOWN if no candidates found at all.
      */
-    static SailPixelFormat closest_pixel_format(SailPixelFormat input_pixel_format, const sail::save_features &save_features);
+    static SailPixelFormat closest_pixel_format(SailPixelFormat input_pixel_format,
+                                                const sail::save_features& save_features);
+
+    /*
+     * Returns the number of channels in the specified pixel format.
+     * For example, for SAIL_PIXEL_FORMAT_BPP24_RGB 3 is returned. Returns 0 on unknown pixel layouts.
+     */
+    static unsigned pixel_format_channels(SailPixelFormat pixel_format);
 
     /*
      * Returns the number of bits per pixel of the specified pixel format.
@@ -652,6 +713,12 @@ public:
      */
     static bool is_rgb_family(SailPixelFormat pixel_format);
 
+    /*
+     * Returns true if the specified pixel format uses floating point representation
+     * (half or single precision).
+     */
+    static bool is_floating_point(SailPixelFormat pixel_format);
+
     /*
      * Returns a string representation of the specified pixel format.
      * For example: "BPP32-RGBA" is returned for SAIL_PIXEL_FORMAT_BPP32_RGBA.
@@ -666,7 +733,7 @@ public:
      *
      * Returns SAIL_PIXEL_FORMAT_UNKNOWN if the pixel format is not known.
      */
-    static SailPixelFormat pixel_format_from_string(const std::string &str);
+    static SailPixelFormat pixel_format_from_string(const std::string& str);
 
     /*
      * Returns a string representation of the specified chroma subsampling.
@@ -682,7 +749,7 @@ public:
      *
      * Returns SAIL_CHROMA_SUBSAMPLING_UNKNOWN if the chroma subsampling is not known.
      */
-    static SailChromaSubsampling chroma_subsampling_from_string(const std::string &str);
+    static SailChromaSubsampling chroma_subsampling_from_string(const std::string& str);
 
     /*
      * Returns a string representation of the specified orientation. See SailOrientation.
@@ -698,7 +765,7 @@ public:
      *
      * Returns SAIL_ORIENTATION_NORMAL if the orientation is not known.
      */
-    static SailOrientation orientation_from_string(const std::string &str);
+    static SailOrientation orientation_from_string(const std::string& str);
 
     /*
      * Returns string representation of the specified compression type. See SailCompression.
@@ -714,34 +781,32 @@ public:
      *
      * Returns SAIL_COMPRESSION_UNKNOWN if the compression is not known.
      */
-    static SailCompression compression_from_string(const std::string &str);
+    static SailCompression compression_from_string(const std::string& str);
 
 private:
     /*
      * Makes a deep copy of the specified image. The pixels are transferred. The caller must set the pixels
      * in the sail_image object to NULL afterwards to avoid destructing them in sail_destroy_image().
      */
-    image(const sail_image *sail_image);
+    image(const sail_image* sail_image);
 
-    sail_status_t transfer_pixels_pointer(const sail_image *sail_image);
+    sail_status_t transfer_pixels_pointer(const sail_image* sail_image);
 
-    sail_status_t to_sail_image(sail_image **image) const;
+    sail_status_t to_sail_image(sail_image** image) const;
 
     void set_dimensions(unsigned width, unsigned height);
     void set_pixel_format(SailPixelFormat pixel_format);
     void set_bytes_per_line(unsigned bytes_per_line);
     void set_bytes_per_line_auto();
-    void set_pixels(const void *pixels);
-    void set_pixels(const void *pixels, std::size_t pixels_size);
-    void set_shallow_pixels(void *pixels);
-    void set_shallow_pixels(void *pixels, std::size_t pixels_size);
-    void set_source_image(const sail::source_image &source_image);
+    void set_pixels(const void* pixels);
+    void set_pixels(const void* pixels, std::size_t pixels_size);
+    void set_shallow_pixels(void* pixels);
+    void set_shallow_pixels(void* pixels, std::size_t pixels_size);
+    void set_source_image(const sail::source_image& source_image);
 
 private:
     class pimpl;
     std::unique_ptr<pimpl> d;
 };
 
-}
-
-#endif
+} // namespace sail
