@@ -35,21 +35,25 @@ namespace sail
 class SAIL_HIDDEN image_output::pimpl
 {
 public:
-    pimpl(sail::abstract_io *abstract_io_ext, const sail::codec_info &other_codec_info)
+    pimpl(sail::abstract_io* abstract_io_ext, const sail::codec_info& other_codec_info)
         : abstract_io(abstract_io_ext)
         , abstract_io_ref(*abstract_io)
+        , our_io(true)
         , abstract_io_adapter(new sail::abstract_io_adapter(abstract_io_ref))
         , state(nullptr)
+        , finished(false)
         , codec_info(other_codec_info)
         , override_save_options(false)
     {
     }
 
-    pimpl(sail::abstract_io &abstract_io_ext, const sail::codec_info &other_codec_info)
+    pimpl(sail::abstract_io& abstract_io_ext, const sail::codec_info& other_codec_info)
         : abstract_io()
         , abstract_io_ref(abstract_io_ext)
+        , our_io(false)
         , abstract_io_adapter(new sail::abstract_io_adapter(abstract_io_ref))
         , state(nullptr)
+        , finished(false)
         , codec_info(other_codec_info)
         , override_save_options(false)
     {
@@ -58,13 +62,28 @@ public:
     sail_status_t start();
 
 private:
-    const std::unique_ptr<sail::abstract_io> abstract_io;
-    sail::abstract_io &abstract_io_ref;
+    std::unique_ptr<sail::abstract_io> abstract_io;
+    sail::abstract_io& abstract_io_ref;
+    bool our_io;
 
 public:
-    const std::unique_ptr<sail::abstract_io_adapter> abstract_io_adapter;
-    void *state;
+    void finish()
+    {
+        if (our_io)
+        {
+            abstract_io.reset();
+        }
+        else
+        {
+            abstract_io_ref.flush();
+        }
+        finished = true;
+    }
 
+    const std::unique_ptr<sail::abstract_io_adapter> abstract_io_adapter;
+    void* state;
+
+    bool finished;
     sail::codec_info codec_info;
     bool override_save_options;
     sail::save_options save_options;
@@ -72,71 +91,74 @@ public:
 
 sail_status_t image_output::pimpl::start()
 {
-    const sail_codec_info *sail_codec_info = codec_info.sail_codec_info_c();
+    const sail_codec_info* sail_codec_info = codec_info.sail_codec_info_c();
 
-    sail_save_options *sail_save_options = nullptr;
+    sail_save_options* sail_save_options = nullptr;
 
     SAIL_AT_SCOPE_EXIT(
         sail_destroy_save_options(sail_save_options);
     );
 
-    if (override_save_options) {
+    if (override_save_options)
+    {
         SAIL_TRY(save_options.to_sail_save_options(&sail_save_options));
     }
 
-    SAIL_TRY(sail_start_saving_into_io_with_options(&abstract_io_adapter->sail_io_c(), sail_codec_info, sail_save_options, &state));
+    SAIL_TRY(sail_start_saving_into_io_with_options(&abstract_io_adapter->sail_io_c(), sail_codec_info,
+                                                    sail_save_options, &state));
 
     return SAIL_OK;
 }
 
-image_output::image_output(const std::string &path)
+image_output::image_output(const std::string& path)
     : d(new pimpl(new io_file(path, io_file::Operation::ReadWrite), sail::codec_info::from_path(path)))
 {
 }
 
-image_output::image_output(void *buffer, std::size_t buffer_size, const sail::codec_info &codec_info)
+image_output::image_output(void* buffer, std::size_t buffer_size, const sail::codec_info& codec_info)
     : d(new pimpl(new io_memory(buffer, buffer_size), codec_info))
 {
 }
 
-image_output::image_output(sail::arbitrary_data *arbitrary_data, const sail::codec_info &codec_info)
+image_output::image_output(sail::arbitrary_data* arbitrary_data, const sail::codec_info& codec_info)
     : image_output(arbitrary_data->data(), arbitrary_data->size(), codec_info)
 {
 }
 
-image_output::image_output(sail::abstract_io &abstract_io, const sail::codec_info &codec_info)
+image_output::image_output(sail::abstract_io& abstract_io, const sail::codec_info& codec_info)
     : d(new pimpl(abstract_io, codec_info))
 {
 }
 
 image_output::~image_output()
 {
-    if (d) {
+    if (d)
+    {
         finish();
     }
 }
 
-image_output::image_output(image_output &&other) noexcept
+image_output::image_output(image_output&& other) noexcept
 {
     *this = std::move(other);
 }
 
-image_output& image_output::operator=(image_output &&other) noexcept
+image_output& image_output::operator=(image_output&& other) noexcept
 {
-    d = std::move(other.d);
+    d       = std::move(other.d);
     other.d = {};
 
     return *this;
 }
 
-image_output& image_output::with(const sail::codec_info &codec_info)
+image_output& image_output::with(const sail::codec_info& codec_info)
 {
     d->codec_info = codec_info;
 
     return *this;
 }
 
-image_output& image_output::with(const sail::save_options &save_options)
+image_output& image_output::with(const sail::save_options& save_options)
 {
     d->override_save_options = true;
     d->save_options          = save_options;
@@ -144,13 +166,18 @@ image_output& image_output::with(const sail::save_options &save_options)
     return *this;
 }
 
-sail_status_t image_output::next_frame(const sail::image &image)
+sail_status_t image_output::next_frame(const sail::image& image)
 {
-    if (d->state == nullptr) {
+    if (d->finished)
+    {
+        return SAIL_ERROR_CONFLICTING_OPERATION;
+    }
+    else if (d->state == nullptr)
+    {
         SAIL_TRY(d->start());
     }
 
-    sail_image *sail_image = nullptr;
+    sail_image* sail_image = nullptr;
     SAIL_TRY(image.to_sail_image(&sail_image));
 
     SAIL_AT_SCOPE_EXIT(
@@ -166,12 +193,18 @@ sail_status_t image_output::next_frame(const sail::image &image)
 sail_status_t image_output::finish()
 {
     sail_status_t saved_status = SAIL_OK;
-    SAIL_TRY_OR_EXECUTE(sail_stop_saving(d->state),
-                        /* on error */ saved_status = __sail_status);
 
-    d->state = nullptr;
+    if (d->state != nullptr)
+    {
+        SAIL_TRY_OR_EXECUTE(sail_stop_saving(d->state),
+                            /* on error */ saved_status = __sail_status);
+
+        d->state = nullptr;
+    }
+
+    d->finish();
 
     return saved_status;
 }
 
-}
+} // namespace sail
