@@ -33,11 +33,26 @@ namespace sail
 namespace log
 {
 
+SailLogLevel level_from_string(const char* str)
+{
+    return sail_log_level_from_string(str);
+}
+
+SailLogLevel level_from_string(const std::string& str)
+{
+    return sail_log_level_from_string(str.c_str());
+}
+
 void set_barrier(SailLogLevel max_level)
 {
     sail_set_log_barrier(max_level);
 }
 
+void set_logger(sail_logger logger)
+{
+    sail_set_logger(logger);
 }
 
-}
+} // namespace log
+
+} // namespace sail
