@@ -23,15 +23,12 @@
     SOFTWARE.
 */
 
-#ifndef SAIL_GIF_IO_H
-#define SAIL_GIF_IO_H
+#pragma once
 
 #include <gif_lib.h>
 
 #include <sail-common/export.h>
 
-SAIL_HIDDEN int my_read_proc(GifFileType *gif, GifByteType *buffer, int buffer_size);
+SAIL_HIDDEN int my_read_proc(GifFileType* gif, GifByteType* buffer, int buffer_size);
 
-SAIL_HIDDEN int my_write_proc(GifFileType *gif, GifByteType *buffer, int buffer_size);
-
-#endif
+SAIL_HIDDEN int my_write_proc(GifFileType* gif, const GifByteType* buffer, int buffer_size);
