@@ -23,14 +23,11 @@
     SOFTWARE.
 */
 
-#ifndef SAIL_JPEGXL_MEMORY_H
-#define SAIL_JPEGXL_MEMORY_H
+#pragma once
 
 #include <sail-common/export.h>
 
 /* We want to allocate/free with sail_malloc()/sail_free(). */
-SAIL_HIDDEN void *jpegxl_private_alloc_func(void *opaque, size_t size);
+SAIL_HIDDEN void* jpegxl_private_alloc_func(void* opaque, size_t size);
 
-SAIL_HIDDEN void jpegxl_private_free_func(void *opaque, void *address);
-
-#endif
+SAIL_HIDDEN void jpegxl_private_free_func(void* opaque, void* address);
