@@ -23,11 +23,40 @@
     SOFTWARE.
 */
 
-#ifndef SAIL_XBM_HELPERS_H
-#define SAIL_XBM_HELPERS_H
+#pragma once
 
+#include <stdbool.h>
+
+#include <sail-common/common.h>
 #include <sail-common/export.h>
+#include <sail-common/status.h>
+
+struct sail_io;
+struct sail_variant;
+
+enum SailXbmVersion
+{
+    SAIL_XBM_VERSION_10 = 10,
+    SAIL_XBM_VERSION_11 = 11,
+};
+
+/*
+ * Tuning state for callback.
+ */
+struct xbm_state
+{
+    enum SailXbmVersion version;
+    char var_name[256];
+};
 
 SAIL_HIDDEN unsigned char xbm_private_reverse_byte(unsigned char byte);
 
-#endif
+SAIL_HIDDEN sail_status_t xbm_private_write_header(
+    struct sail_io* io, unsigned width, unsigned height, const char* name, enum SailXbmVersion version);
+
+SAIL_HIDDEN sail_status_t xbm_private_write_pixels(
+    struct sail_io* io, const unsigned char* pixels, unsigned width, unsigned height, enum SailXbmVersion version);
+
+SAIL_HIDDEN bool xbm_private_tuning_key_value_callback(const char* key,
+                                                       const struct sail_variant* value,
+                                                       void* user_data);
