@@ -23,8 +23,7 @@
     SOFTWARE.
 */
 
-#ifndef SAIL_UTILS_H
-#define SAIL_UTILS_H
+#pragma once
 
 #include <stdbool.h>
 #include <stddef.h> /* size_t */
@@ -42,7 +41,8 @@ struct sail_image;
 #define SAIL_MAX(a, b) (((a) > (b)) ? (a) : (b))
 
 #ifdef __cplusplus
-extern "C" {
+extern "C"
+{
 #endif
 
 /*
@@ -50,14 +50,14 @@ extern "C" {
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_memdup(const void *input, size_t input_size, void **output);
+SAIL_EXPORT sail_status_t sail_memdup(const void* input, size_t input_size, void** output);
 
 /*
  * Duplicates the specified string and stores a new string in the specified output.
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_strdup(const char *input, char **output);
+SAIL_EXPORT sail_status_t sail_strdup(const char* input, char** output);
 
 /*
  * Duplicates the specified number of bytes of the specified input string and stores
@@ -65,37 +65,48 @@ SAIL_EXPORT sail_status_t sail_strdup(const char *input, char **output);
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_strdup_length(const char *input, size_t length, char **output);
+SAIL_EXPORT sail_status_t sail_strdup_length(const char* input, size_t length, char** output);
 
 /*
  * Concatenates 'num' number of strings together and puts the result into the specified output string.
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_concat(char **output, int num, ...);
+SAIL_EXPORT sail_status_t sail_concat(char** output, int num, ...);
 
 /*
  * Converts the specified string to a lower case.
  */
-SAIL_EXPORT void sail_to_lower(char *str);
+SAIL_EXPORT void sail_to_lower(char* str);
+
+/*
+ * Converts the specified string to an upper case.
+ */
+SAIL_EXPORT void sail_to_upper(char* str);
 
 /*
  * Converts the specified char* string into a wchar_t* string.
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_to_wchar(const char *input, wchar_t **output);
+SAIL_EXPORT sail_status_t sail_to_wchar(const char* input, wchar_t** output);
 
 /*
  * Computes a unique hash of the specified string. It utilizes the djb2 algorithm proposed by Dan Bernstein.
  *
  * Returns 0 if the string is NULL or empty.
  */
-SAIL_EXPORT uint64_t sail_string_hash(const char *str);
+SAIL_EXPORT uint64_t sail_string_hash(const char* str);
+
+/*
+ * Returns the number of channels in the specified pixel format.
+ * For example, for SAIL_PIXEL_FORMAT_BPP24_RGB 3 is returned. Returns 0 on unknown pixel layouts.
+ */
+SAIL_EXPORT unsigned sail_pixel_format_channels(enum SailPixelFormat pixel_format);
 
 /*
  * Returns the number of bits per pixel of the specified pixel format.
- * For example, for SAIL_PIXEL_FORMAT_RGB 24 is returned. Returns 0 on unknown pixel format.
+ * For example, for SAIL_PIXEL_FORMAT_BPP24_RGB 24 is returned. Returns 0 on unknown pixel format.
  */
 SAIL_EXPORT unsigned sail_bits_per_pixel(enum SailPixelFormat pixel_format);
 
@@ -117,7 +128,8 @@ SAIL_EXPORT bool sail_equal_bits_per_pixel(enum SailPixelFormat pixel_format1, e
 /*
  * Returns true if the first pixel format occupies more or the same number of bits than the second one.
  */
-SAIL_EXPORT bool sail_greater_equal_bits_per_pixel(enum SailPixelFormat pixel_format1, enum SailPixelFormat pixel_format2);
+SAIL_EXPORT bool sail_greater_equal_bits_per_pixel(enum SailPixelFormat pixel_format1,
+                                                   enum SailPixelFormat pixel_format2);
 
 /*
  * Returns true if the first pixel format occupies more bits than the second one.
@@ -154,10 +166,30 @@ SAIL_EXPORT bool sail_is_grayscale(enum SailPixelFormat pixel_format);
  */
 SAIL_EXPORT bool sail_is_rgb_family(enum SailPixelFormat pixel_format);
 
+/*
+ * Returns true if the given pixel format uses floating point representation (half or single precision).
+ */
+SAIL_EXPORT bool sail_is_floating_point(enum SailPixelFormat pixel_format);
+
+/*
+ * Returns true if the given pixel format is CMYK, with or without alpha.
+ */
+SAIL_EXPORT bool sail_is_cmyk(enum SailPixelFormat pixel_format);
+
+/*
+ * Returns true if the given pixel format is YCbCr.
+ */
+SAIL_EXPORT bool sail_is_ycbcr(enum SailPixelFormat pixel_format);
+
+/*
+ * Returns true if the given pixel format is YCCK.
+ */
+SAIL_EXPORT bool sail_is_ycck(enum SailPixelFormat pixel_format);
+
 /*
  * Prints the recent errno value with SAIL_LOG_ERROR(). The specified format must include '%s'.
  */
-SAIL_EXPORT void sail_print_errno(const char *format);
+SAIL_EXPORT void sail_print_errno(const char* format);
 
 /*
  * Returns the current number of milliseconds since Epoch or 0 on error.
@@ -167,31 +199,43 @@ SAIL_EXPORT uint64_t sail_now(void);
 /*
  * Returns true if the specified file system path exists.
  */
-SAIL_EXPORT bool sail_path_exists(const char *path);
+SAIL_EXPORT bool sail_path_exists(const char* path);
 
 /*
  * Returns true if the specified file system path is a directory.
  */
-SAIL_EXPORT bool sail_is_dir(const char *path);
+SAIL_EXPORT bool sail_is_dir(const char* path);
 
 /*
  * Returns true if the specified file system path is a regular file.
  */
-SAIL_EXPORT bool sail_is_file(const char *path);
+SAIL_EXPORT bool sail_is_file(const char* path);
+
+/*
+ * Returns a temporary file path with the specified prefix. The caller is responsible
+ * for deleting the file and the path when it's no longer needed. The prefix can be
+ * empty or NULL, in which case a default prefix will be used.
+ *
+ * Note: The returned path is guaranteed to be unique, but the file may not exist yet.
+ *       The caller must create the file (e.g., with O_CREAT flag on POSIX or _O_CREAT on Windows).
+ *
+ * Returns SAIL_OK on success.
+ */
+SAIL_EXPORT sail_status_t sail_temp_file_path(const char* prefix, char** path);
 
 /*
  * Retrieves the file size.
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_file_size(const char *path, size_t *size);
+SAIL_EXPORT sail_status_t sail_file_size(const char* path, size_t* size);
 
 /*
  * Reads the specified file into the memory buffer. The buffer must be large enough.
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_file_contents_into_data(const char *path, void *data);
+SAIL_EXPORT sail_status_t sail_file_contents_into_data(const char* path, void* data);
 
 /*
  * Allocates a memory buffer and reads the specified file into it.
@@ -199,7 +243,7 @@ SAIL_EXPORT sail_status_t sail_file_contents_into_data(const char *path, void *d
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_alloc_data_from_file_contents(const char *path, void **data, size_t *data_size);
+SAIL_EXPORT sail_status_t sail_alloc_data_from_file_contents(const char* path, void** data, size_t* data_size);
 
 /*
  * Decodes the specified HEX-encoded string into the specified memory buffer.
@@ -208,7 +252,7 @@ SAIL_EXPORT sail_status_t sail_alloc_data_from_file_contents(const char *path, v
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_hex_string_into_data(const char *str, void *data);
+SAIL_EXPORT sail_status_t sail_hex_string_into_data(const char* str, void* data);
 
 /*
  * Allocates a memory buffer and decodes the specified HEX-encoded string into it.
@@ -217,7 +261,7 @@ SAIL_EXPORT sail_status_t sail_hex_string_into_data(const char *str, void *data)
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_hex_string_to_data(const char *str, void **data, size_t *data_size);
+SAIL_EXPORT sail_status_t sail_hex_string_to_data(const char* str, void** data, size_t* data_size);
 
 /*
  * Encodes the specified memory buffer into the HEX-encoded string. The string must be large enough.
@@ -225,7 +269,7 @@ SAIL_EXPORT sail_status_t sail_hex_string_to_data(const char *str, void **data,
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_data_into_hex_string(const void *data, size_t data_size, char *str);
+SAIL_EXPORT sail_status_t sail_data_into_hex_string(const void* data, size_t data_size, char* str);
 
 /*
  * Allocates a string and HEX-encodes the specified memory buffer into it.
@@ -233,7 +277,7 @@ SAIL_EXPORT sail_status_t sail_data_into_hex_string(const void *data, size_t dat
  *
  * Returns SAIL_OK on success.
  */
-SAIL_EXPORT sail_status_t sail_data_to_hex_string(const void *data, size_t data_size, char **str);
+SAIL_EXPORT sail_status_t sail_data_to_hex_string(const void* data, size_t data_size, char** str);
 
 /*
  * Reverses the input value byte order.
@@ -262,12 +306,10 @@ SAIL_EXPORT uint64_t sail_reverse_uint64(uint64_t v);
  * Returns SAIL_OK on success.
  */
 #ifdef SAIL_WINDOWS_UTF8_PATHS
-SAIL_EXPORT sail_status_t sail_multibyte_to_wchar(const char *str, wchar_t **wstr);
+SAIL_EXPORT sail_status_t sail_multibyte_to_wchar(const char* str, wchar_t** wstr);
 #endif
 
 /* extern "C" */
 #ifdef __cplusplus
 }
 #endif
-
-#endif
